==> openjdk-10_10~32.orig.tar.xz: openjdk-10-10~32/src/hotspot/share/gc/shared/cardTableModRefBS.inline.hpp <==
/*
 * Copyright (c) 2000, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_VM_GC_SHARED_CARDTABLEMODREFBS_INLINE_HPP
#define SHARE_VM_GC_SHARED_CARDTABLEMODREFBS_INLINE_HPP

#include "gc/shared/cardTableModRefBS.hpp"
#include "oops/oopsHierarchy.hpp"
#include "runtime/orderAccess.inline.hpp"

template <class T> inline void CardTableModRefBS::inline_write_ref_field(T* field, oop newVal, bool release) {
  volatile jbyte* byte = byte_for((void*)field);
  if (release) {
    // Perform a releasing store if requested.
    OrderAccess::release_store(byte, jbyte(dirty_card));
  } else {
    *byte = dirty_card;
  }
}

#endif // SHARE_VM_GC_SHARED_CARDTABLEMODREFBS_INLINE_HPP

==> openjdk-11_11~4.orig.tar.xz: openjdk-11-11~4/src/hotspot/share/gc/shared/cardTableModRefBS.inline.hpp <==
/*
 * Copyright (c) 2000, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_VM_GC_SHARED_CARDTABLEMODREFBS_INLINE_HPP
#define SHARE_VM_GC_SHARED_CARDTABLEMODREFBS_INLINE_HPP

#include "gc/shared/cardTableModRefBS.hpp"
#include "gc/shared/cardTable.hpp"
#include "runtime/orderAccess.inline.hpp"

template <DecoratorSet decorators, typename T>
inline void CardTableModRefBS::write_ref_field_post(T* field, oop newVal) {
  volatile jbyte* byte = _card_table->byte_for(field);
  if (UseConcMarkSweepGC) {
    // Perform a releasing store if using CMS so that it may
    // scan and clear the cards concurrently during pre-cleaning.
    OrderAccess::release_store(byte, CardTable::dirty_card_val());
  } else {
    *byte = CardTable::dirty_card_val();
  }
}

#endif // SHARE_VM_GC_SHARED_CARDTABLEMODREFBS_INLINE_HPP
